class tails::builder (
  $http_proxy = undef,
) {

  ### Sanity checks

  if $http_proxy {
    validate_string($http_proxy)
  }

  if $::lsbdistcodename != 'wheezy' {
    fail('The tails::builder module only supports Debian Wheezy.')
  }

  ### Resources

  apt::sources_list { 'tails-builder-wheezy.list':
    content => "deb http://deb.tails.boum.org/ builder-wheezy main\n",
    require => Exec['custom_keys'],
  }

  apt::preferences_snippet { ['eatmydata', 'gettext', 'ikiwiki']:
    pin      => 'release o=Debian Backports,a=wheezy-backports',
    priority => 991,
  }

  apt::preferences_snippet { ['live-build', 'syslinux-utils']:
    pin      => 'origin deb.tails.boum.org',
    priority => 991,
  }

  $builder_packages = [
    'dpkg-dev',
    'eatmydata',
    'ikiwiki',
    'libyaml-perl',
    'libyaml-libyaml-perl',
    'libyaml-syck-perl',
    'live-build',
    'perlmagick',
    'po4a',
    'syslinux-utils',
    'time',
    'whois',
    'intltool',
  ]

  package { $builder_packages:
    ensure  => present,
    require => [
      Apt::Sources_list['tails-builder-wheezy.list'],
      Apt::Preferences_snippet['ikiwiki', 'live-build'],
    ],
  }

  ensure_packages(['sudo'])

  file { '/etc/live':
    ensure => directory,
    owner  => root,
    group  => root,
    mode   => '0755',
  }

  file { '/etc/live/build.conf':
    owner => root,
    group => root,
    mode  => '0644',
  }

  file { '/etc/sudoers.d/tails-builder-defaults':
    owner   => root,
    group   => root,
    mode    => '0440',
    content => "Defaults secure_path=\"/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin\"\n",
    require => File_line['sudo-includedir-sudoers.d'],
  }

  file_line { 'sudo-includedir-sudoers.d':
    ensure  => present,
    path    => '/etc/sudoers',
    line    => '#includedir /etc/sudoers.d',
    require => Package['sudo'],
  }

  if $http_proxy {
    augeas { 'tails_builder_live-build.conf_http_proxy':
      lens    => 'Shellvars.lns',
      incl    => '/etc/live/build.conf',
      changes => "set LB_APT_HTTP_PROXY ${http_proxy}",
      require => File['/etc/live/build.conf'],
    }
  }

}
