# Configure an APT proxy for Tails' Jenkins use
class tails::jenkins::apt_proxy (
  $jenkins_ssh_keyname = 'jenkins@jenkins-slave',
  $jenkins_user_password
) {

  # Let apt-cacher-ng proxy firmwares for builds.
  file { '/etc/apt-cacher-ng/builds.conf':
    source  => 'puppet:///modules/tails/apt-cacher-ng/isobuilds.conf',
    require => Package['apt-cacher-ng'],
    owner   => root,
    group   => root,
    mode    => '0644',
  }

  # Allow the jenkins user on Jenkins slaves to sftp in: the ISO builders
  # need to retrieve apt-cacher-ng's log file to build the list of packages
  # that were used during the build.

  user { 'jenkins':
    ensure     => present,
    system     => true,
    home       => '/var/lib/jenkins',
    shell      => '/usr/lib/openssh/sftp-server',
    managehome => true,
    password   => $jenkins_user_password,
  }

  sshkeys::set_authorized_keys{'jenkins@jenkins-slave_to_jenkins@apt-proxy':
    keyname => $jenkins_ssh_keyname,
    user    => 'jenkins',
    home    => '/var/lib/jenkins',
    require => User['jenkins'],
  }


}
