# Install the cronjob and scripts necessary to automatically update the
# build_Tails_ISO_* jobs in Jenkins.
class tails::jenkins::iso_jobs_generator (
  $ensure            = 'present',
  $tails_repo        = 'https://git-tails.immerda.ch/tails',
  $jenkins_jobs_repo,
) {

  ### Sanity checks

  validate_string(
    $jenkins_jobs_repo,
    $tails_repo
  )

  if !defined(Class['tails::pythonlib']) {
    include tails::pythonlib
  }

  ensure_packages(
    ['python3-yaml'],
    {'ensure' => $ensure}
  )

  file { '/usr/local/sbin/generate_tails_iso_jobs':
    ensure  => $ensure,
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    source  => 'puppet:///modules/tails/jenkins/master/generate_tails_iso_jobs',
    require => Vcsrepo['/var/lib/tails_pythonlib/git'],
  }

  file { '/usr/local/sbin/update_tails_iso_jobs':
    ensure  => $ensure,
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    source  => 'puppet:///modules/tails/jenkins/master/update_tails_iso_jobs',
    require => File['/usr/local/sbin/generate_tails_iso_jobs'],
  }

  cron {'update_tails_iso_jobs':
    ensure  => $ensure,
    minute  => '*/5',
    user    => 'jenkins',
    command => "/usr/local/sbin/update_tails_iso_jobs '${tails_repo}' '${jenkins_jobs_repo}'",
    require => File['/usr/local/sbin/update_tails_iso_jobs'],
  }

}
