class tails::jenkins::slave (
  $master_url,
) {

  ### Sanity checks

  if $::osfamily != 'Debian' {
    fail('The tails::jenkins::slave class only supports Debian.')
  }
  
  validate_string($master_url)

  ### Resources

  apt::sources_list { 'sid.list':
    content => "deb http://httpredir.debian.org/debian/ unstable main\n",
  }

  apt::preferences_snippet { ['jenkins-slave']:
      pin      => 'release o=Debian,a=unstable',
      priority => 991,
      require  => Apt::Sources_list['sid.list'],
  }

  package { 'jenkins-slave':
    ensure  => present,
    require => Apt::Preferences_snippet['jenkins-slave'],
  }

  file_line { 'master_url':
    path    => '/etc/default/jenkins-slave',
    match   => '#?JENKINS_URL=(?:".*")?',
    line    => "JENKINS_URL='${master_url}'",
    require => Package['jenkins-slave'],
  }

  service { 'jenkins-slave':
    ensure    => running,
    hasstatus => false,
    pattern   => '/usr/bin/daemon --name=jenkins-slave',
    require   => File_line['master_url'],
  }

  file { '/var/lib/jenkins':
    ensure  => directory,
    owner   => jenkins,
    group   => jenkins,
    mode    => '0755',
    require => Package['jenkins-slave'],
  }

  file { '/var/lib/jenkins/.ssh':
    ensure  => directory,
    owner   => jenkins,
    group   => jenkins,
    mode    => '0700',
    require => File['/var/lib/jenkins'],
  }

  # SSH keys

  sshkeys::set_client_key_pair { 'jenkins@jenkins-slave':
    keyname => 'jenkins@jenkins-slave',
    user    => 'jenkins',
    home    => '/var/lib/jenkins',
    require => File['/var/lib/jenkins/.ssh'],
  }

}
