class tails::jenkins::slave::iso_tester (
  $master_url,
  $config_basedir          = '/etc/TailsToaster',
  $manage_temp_dir_mount   = false,
  $temp_dir                = '/tmp/TailsToaster',
  $temp_dir_backing_device = undef,
  $temp_dir_fs_type        = 'ext4',
  $temp_dir_mount_options  = 'relatime,acl',
) {

  validate_string(
    $master_url,
  )

  user { 'jenkins':
    membership => minimum,
    groups     => [ 'sudo' ],
    system     => true,
  }

  class { '::tails::jenkins::slave':
    master_url => $master_url,
    require    => User['jenkins'],
  } -> class { 'tails::tester::check_po': }

  class { '::tails::tester':
    manage_temp_dir_mount   => $manage_temp_dir_mount,
    temp_dir_backing_device => $temp_dir_backing_device,
    temp_dir                => $temp_dir,
    temp_dir_fs_type        => $temp_dir_fs_type,
    temp_dir_mount_options  => $temp_dir_mount_options,
  }

  file {
    $config_basedir:
      ensure => directory,
      mode   => '0755',
      owner  => 'root',
      group  => 'root';
    "${config_basedir}/common.d":
      source  => 'puppet:///modules/tails_secrets_jenkins/jenkins/slaves/isotesters/TailsToaster_config/common.d',
      owner   => 'jenkins',
      group   => 'jenkins',
      recurse => true;
    "${config_basedir}/local.d":
      source  => "puppet:///modules/tails_secrets_jenkins/jenkins/slaves/${::fqdn}/TailsToaster_config",
      owner   => 'jenkins',
      group   => 'jenkins',
      recurse => true;
  }

  file { '/var/lib/jenkins/.netrc':
    mode   => '0600',
    owner  => 'jenkins',
    group  => 'jenkins',
    source => 'puppet:///modules/tails_secrets_jenkins/jenkins/slaves/isotesters/iso-history/netrc',
  }

  file { '/usr/local/bin/test_suite_temp_wrapper':
    source => 'puppet:///modules/tails/jenkins/slaves/isotesters/test_suite_temp_wrapper',
    mode   => '0755',
    owner  => 'root',
    group  => 'root',
  }

  file { '/usr/local/bin/wrap_test_suite':
    source => 'puppet:///modules/tails/jenkins/slaves/isotesters/wrap_test_suite',
    mode   => '0755',
    owner  => 'root',
    group  => 'root',
  }

  file { '/usr/local/bin/post_test_cleanup':
    source => 'puppet:///modules/tails/jenkins/slaves/isotesters/post_test_cleanup',
    mode   => '0755',
    owner  => 'root',
    group  => 'root',
  }

  # Prevent some Recommends pulled by GTK3 to be installed.
  # Some of them imply running daemons we don't need, which slows down the boot
  # ... and we're going to reboot these VMs quite often.
  package { ['colord', 'libsane', 'sane-utils']:
    ensure => absent,
  }

}
