# Deploy the Tails pythonlib on systems from git.
# The `$ensure' parameter is passed through to Vcsrepo resources,
# and (with some translation) to File and ensure_packages resources.
class tails::pythonlib (
  $ensure        = 'latest',
  $clone_basedir = '/var/lib/tails_pythonlib',
  $repo_origin   = 'https://git-tails.immerda.ch/pythonlib',
  $repo_rev      = 'master',
  $repo_user     = 'root',
) {

  validate_absolute_path($clone_basedir)
  validate_string(
    $ensure,
    $repo_origin,
    $repo_rev,
    $repo_user,
  )

  $directory_ensure = $ensure ? {
    absent  => absent,
    default => directory,
  }

  file { $clone_basedir:
    ensure => $directory_ensure,
    owner  => $repo_user,
    group  => $repo_user,
    mode   => '0755',
  }

  $package_ensure = $ensure ? {
    absent  => absent,
    default => present,
  }

  ensure_packages(
    ['python3-sh'],
    {'ensure' => $package_ensure}
  )

  vcsrepo { "${clone_basedir}/git":
    ensure   => $ensure,
    provider => git,
    source   => $repo_origin,
    revision => $repo_rev,
    user     => $repo_user,
    require  => File[$clone_basedir],
  }

  # XXX: support $ensure = absent
  exec { 'install_tails_pythonlib':
    user        => root,
    group       => root,
    cwd         => "${clone_basedir}/git",
    command     => "python3 ${clone_basedir}/git/setup.py clean && python3 ${clone_basedir}/git/setup.py install",
    subscribe   => Vcsrepo["${clone_basedir}/git"],
    refreshonly => true,
    require     => Vcsrepo["${clone_basedir}/git"],
  }
}
