# Resources that are shared between tails::reprepro::snapshots::* classes.
define tails::reprepro::snapshots::base (
  $homedir,
  $repositories_dir,
  $user,
  $ensure = present,
) {

  ### Sanity checks

  validate_absolute_path($homedir)
  validate_absolute_path($repositories_dir)
  validate_string($user)
  validate_re($ensure, '^(present|absent)$')

  ### Pull in external dependencies

  if !defined(Class['::reprepro']) {
    class { '::reprepro':
      ensure => $ensure,
    }
  }

  ### Resources

  $directory_ensure = $ensure ? {
    absent  => absent,
    default => directory,
  }

  user { $user:
    ensure   => $ensure,
    home     => $homedir,
    gid      => $user,
    password => '*',
    comment  => 'Tails snapshots of APT repositories',
    require  => Group[$user],
  }

  group { $user:
    ensure => $ensure,
  }

  file { [$homedir, $repositories_dir]:
    ensure => $directory_ensure,
    owner  => $user,
    group  => $user,
    mode   => '0751',
  }

  # reprepro::repository manages the permissions of its own $homedir/.gnupg
  # (that is, a subdirectory of our $homedir), but not those of ~/.gnupg
  file { "${homedir}/.gnupg":
    ensure => $directory_ensure,
    owner  => $user,
    group  => $user,
    mode   => '0700',
  }

}
