# Manage tagged snapshots of the set of APT repositories Tails needs,
# in a reprepro setup.
class tails::reprepro::snapshots::tagged (
  $ensure   = present,
  $homedir           = '/srv/apt-snapshots/tagged',
  $signwith          = $tails::reprepro::snapshots::params::signwith,
  $user              = 'reprepro-tagged-snapshots',
) inherits tails::reprepro::snapshots::params {

  ### Sanity checks

  validate_re($ensure, '^(present|absent)$')

  ### Resources

  $repositories_dir = "${homedir}/repositories"

  $package_ensure = $ensure ? {
    absent  => absent,
    default => present,
  }

  tails::reprepro::snapshots::base {'tagged':
    ensure  => $ensure,
    homedir => $homedir,
    repositories_dir => $repositories_dir,
    user    => $user,
  }

  $prepare_tagged_snashot_import_pkg_deps = [
    libfile-slurp-perl,
    libyaml-libyaml-perl,
    liblist-compare-perl,
    liblist-moreutils-perl,
  ]
  ensure_packages(
    $prepare_tagged_snashot_import_pkg_deps,
    {'ensure' => $package_ensure}
  )

  file { '/usr/local/bin/tails-prepare-tagged-apt-snapshot-import':
    ensure  => $ensure,
    owner   => root,
    group   => root,
    mode    => '0755',
    source  => 'puppet:///modules/tails/reprepro/snapshots/tagged/tails-prepare-tagged-apt-snapshot-import',
    require => Package[$prepare_tagged_snashot_import_pkg_deps],
  }
  
  # XXX: missing bits
  # - import pubkey to verify time-based snapshots we're fetching packages from
  # - import OpenPGP signing key

}
