# Set up what's necessary to run automated tests
class tails::tester (
  $manage_temp_dir_mount   = false,
  $temp_dir                = '/tmp/TailsToaster',
  $temp_dir_backing_device = undef,
  $temp_dir_fs_type        = 'ext4',
  $temp_dir_mount_options  = 'relatime,acl',
) {

  ### Sanity checks

  if $::lsbdistcodename != 'jessie' {
    fail('The tails::tester module only supports Debian Jessie.')
  }

  ### Resources

  class { '::libvirt::host':
    qemu_security_driver => 'none',
  }

  apt::preferences_snippet {
    [ 'cucumber', 'ipxe-qemu', 'libspice-server1', 'libusb', 'libvirt0',
      'libvirt-bin', 'libvirt-dev', 'ovmf', 'python-libvirt', 'qemu',
      'qemu-kvm', 'qemu-system-x86', 'qemu-utils', 'ruby-gherkin',
      'ruby-multi-json', 'ruby-packetfu', 'ruby-rjb', 'seabios'
      ]:
      ensure => absent,
  }

  apt::preferences_snippet { 'python-potr':
    pin      => 'release o=Debian Backports,a=jessie-backports',
    priority => 991,
  }

  $tester_packages = [
    'cucumber',
    'devscripts',
    'dnsmasq-base',
    'gawk',
    'git',
    'i18nspector',
    'libav-tools',
    'libcap2-bin',
    'libsikuli-script-java',
    'libvirt0',
    'libvirt-clients',
    'libvirt-daemon-system',
    'libvirt-dev',
    'libvpx1',
    'ntp',
    'openjdk-7-jre',
    'ovmf',
    'python-jabberbot',
    'python-potr',
    'qemu-kvm',
    'qemu-system-x86',
    'ruby-guestfs',
    'ruby-json',
    'ruby-libvirt',
    'ruby-net-irc',
    'ruby-packetfu',
    'ruby-rb-inotify',
    'ruby-rjb',
    'ruby-rspec',
    'ruby-test-unit',
    'seabios',
    'tcpdump',
    'unclutter',
    'virt-viewer',
    'x11vnc',
    'x264',
    'xtightvncviewer',
    'xvfb',
  ]

  ensure_packages($tester_packages)

  if $manage_temp_dir_mount {

    validate_string(
      $temp_dir,
      $temp_dir_backing_device,
      $temp_dir_fs_type,
      $temp_dir_mount_options
    )

    file { $temp_dir:
      ensure => directory,
      owner  => root,
      group  => root,
      mode   => '0755',
    }

    mount { $temp_dir:
      ensure  => mounted,
      device  => $temp_dir_backing_device,
      fstype  => $temp_dir_fs_type,
      options => $temp_dir_mount_options,
      require => File[$temp_dir]
    }

  }
}
