# Manage a SFTP user for the automated test suite

class tails::tester::support::sftp (
  $user = 'autotest-sftp',
  $home = '/var/lib/autotest-sftp',
  $password,
  $ssh_pub_key,
  $ssh_pub_key_type,
) {

  ### Sanity checks

  validate_string($user)
  validate_absolute_path($home)
  validate_string($password)
  validate_string($ssh_pub_key)
  validate_string($ssh_pub_key_type)

  ### Resources

  ensure_packages(['openssh-sftp-server'])
  
  user { $user:
    ensure     => present,
    shell      => '/usr/lib/openssh/sftp-server',
    system     => true,
    home       => $home,
    managehome => true,
    password   => $password,
    require    => Package['openssh-sftp-server'],
  }
  file { [$home, "${home}/.ssh"]:
    ensure  => directory,
    owner   => $user,
    group   => $user,
    mode    => '0700',
    require => User[$user],
  }
  ssh_authorized_key { $user:
    ensure  => present,
    user    => $user,
    type    => $ssh_pub_key_type,
    key     => $ssh_pub_key,
    require => File["${home}/.ssh"],
  }

}
