# Manage a SSH user with a fake login prompt for the automated test suite

class tails::tester::support::ssh (
  $user = 'autotest-ssh',
  $home = '/var/lib/autotest-ssh',
  $password,
  $ssh_pub_key,
  $ssh_pub_key_type,
) {

  ### Sanity checks

  validate_string($user)
  validate_absolute_path($home)
  validate_string($password)
  validate_string($ssh_pub_key)
  validate_string($ssh_pub_key_type)

  ### Resources

  ensure_packages([falselogin])
  
  file { '/etc/falselogin.conf':
    content => "%user%@%host% ~$ \n",
    owner   => root,
    group   => root,
    mode    => '0644',
    require => Package[falselogin],
  }
  user { $user:
    ensure     => present,
    shell      => '/usr/bin/falselogin',
    system     => true,
    home       => $home,
    managehome => true,
    password   => $password,
    require    => Package[falselogin],
  }
  file { [$home, "${home}/.ssh"]:
    ensure  => directory,
    owner   => $user,
    group   => $user,
    mode    => '0700',
    require => User[$user],
  }
  ssh_authorized_key { $user:
    ensure  => present,
    user    => $user,
    type    => $ssh_pub_key_type,
    key     => $ssh_pub_key,
    require => File["${home}/.ssh"],
  }

}
